/* 
 * Copyright 2002-2004 The Apache Software Foundation
 * Licensed  under the  Apache License,  Version 2.0  (the "License");
 * you may not use  this file  except in  compliance with the License.
 * You may obtain a copy of the License at 
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed  under the  License is distributed on an "AS IS" BASIS,
 * WITHOUT  WARRANTIES OR CONDITIONS  OF ANY KIND, either  express  or
 * implied.
 * 
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.avalon.excalibur.datasource.ids;

import java.math.BigDecimal;

import org.apache.avalon.framework.component.Component;

/**
 * 
 * @author <a href="mailto:dev@avalon.apache.org">Avalon Development Team</a>
 * @version CVS $Revision: 1.4 $ $Date: 2004/02/28 11:47:17 $
 * @since 4.1
 */
public interface IdGenerator
    extends Component
{
    /**
     * The name of the role for convenience
     */
    String ROLE = IdGenerator.class.getName();

    /**
     * Returns the next Id from the pool.
     *
     * @return the next Id.
     */
    BigDecimal getNextBigDecimalId()
        throws IdException;

    /**
     * Returns the next Id from the pool.
     *
     * @return the next Id.
     *
     * @throws IllegalStateException if the next id is outside of the range of valid longs.
     */
    long getNextLongId()
        throws IdException;

    /**
     * Returns the next Id from the pool.
     *
     * @return the next Id.
     *
     * @throws IllegalStateException if the next id is outside of the range of valid integers.
     */
    int getNextIntegerId()
        throws IdException;

    /**
     * Returns the next Id from the pool.
     *
     * @return the next Id.
     *
     * @throws IllegalStateException if the next id is outside of the range of valid shorts.
     */
    short getNextShortId()
        throws IdException;

    /**
     * Returns the next Id from the pool.
     *
     * @return the next Id.
     *
     * @throws IllegalStateException if the next id is outside of the range of valid bytes.
     */
    byte getNextByteId()
        throws IdException;
}

